#This programe is written for understand package distribution on pip for open source
'''Code written by EP on 23/6/22
on the importing of the package it will ask for enter name and once valid input given then return a short msg
package name = printName
main code file name = pN.py

'''


def NamePrint():
    def PassName(x):
        Result = "Hello {}! happy to see you here. V-2(ep22)"
        print(Result.format(x))

    x = input ("Enter your Name\t")
    PassName(x)



#This is setup.py file to set all details of the package here

from setuptools import setup

__project__ = "ep22"
__version__ = "0.0.1"
__description__ = "This is test package to learn distribution on open source"
__packages__ = ["printName"]
__author__ = "EP"


setup(
    name = __project__,
    version = __version__,
    description = __description__,
    packages = __packages__,
    author = __author__,
    )
